import http from "http";
import { WebSocketServer } from "ws";
import { OCPP } from "../index.mjs";

const PORT = 9220;

const server = http.createServer();
const wss = new WebSocketServer({ server });
const ocpp = new OCPP(wss);

ocpp.handle("Heartbeat", (msg, reply) => {
  reply(null, {
    currentTime: new Date().toISOString(),
  });
});

ocpp.handle("BootNotification", (msg, reply) => {
  console.log(msg.action);
  reply(null, {
    currentTime: new Date().toISOString(),
    interval: 60,
    status: "Accepted",
  });

  setTimeout(() => {
    ocpp
      .call(msg.chargeBoxId, "RemoteStartTransaction", {
        connectorId: 1,
        idTag: "04B0267AE05C87",
      })
      .then((val) => {
        console.log("CALLRESULT:RemoteStartTransaction", val);
      });
  }, 3000);
});

ocpp.handle("Authorize", (msg, reply) => {
  reply(null, {
    status: "Accepted",
  });
});

server.listen(PORT, () => {
  console.log("\x1b[42m %s \x1b[0m", `server listening at port ${PORT}`);
});
